@@ -1,3 +1,11 @@
+/*
+* Copyright (c) 2014 Christian Surlykke
+*
+* This file is part of the LXQt project. <https://lxqt.org>
+* It is distributed under the LGPL 2.1 or later license.
+* Please refer to the LICENSE file for a copy of the license.
+*/
+
 #include "batteryinfodialog.h"
 #include "ui_batteryinfodialog.h"
 
@@ -22,7 +30,7 @@ BatteryInfoDialog::BatteryInfoDialog(QList<Solid::Battery*> batteries, QWidget *
     {
         QTabWidget *tabWidget = new QTabWidget(this);
         ui->verticalLayout->insertWidget(0, tabWidget);
-        foreach (Solid::Battery *battery, batteries)
+        for (Solid::Battery *const battery : qAsConst(batteries))
         {
             BatteryInfoFrame *batteryInfoFrame = new BatteryInfoFrame(battery);
             tabWidget->addTab(batteryInfoFrame, "BAT");
